@@ -1,5 +1,5 @@
-/*
- *    Copyright 2010-2012 The MyBatis Team
+/**
+ *    Copyright 2010-2015 the original author or authors.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -46,6 +46,7 @@ final class ExecutorInterceptor implements Interceptor {
 
   private boolean closed;
 
+  @Override
   public Object intercept(Invocation invocation) throws Throwable {
     if ("commit".equals(invocation.getMethod().getName())) {
       ++this.commitCount;
@@ -58,10 +59,12 @@ final class ExecutorInterceptor implements Interceptor {
     return invocation.proceed();
   }
 
+  @Override
   public Object plugin(Object target) {
     return Plugin.wrap(target, this);
   }
 
+  @Override
   public void setProperties(Properties properties) {
     // do nothing
   }
