@@ -1,5 +1,5 @@
-/*
- *    Copyright 2010-2012 The MyBatis Team
+/**
+ *    Copyright 2010-2015 the original author or authors.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ import org.springframework.transaction.support.TransactionSynchronizationManager
 
 // tests basic usage and implementation only
 // MapperFactoryBeanTest handles testing the transactional functions in SqlSessionTemplate
-public final class SqlSessionTemplateTest extends AbstractMyBatisSpringTest {
+public class SqlSessionTemplateTest extends AbstractMyBatisSpringTest {
 
   private static SqlSession sqlSessionTemplate;
 
@@ -180,7 +180,7 @@ public final class SqlSessionTemplateTest extends AbstractMyBatisSpringTest {
     sqlSessionTemplate.getMapper(TestMapper.class).findTest();
 
     txManager.commit(status);
-
+    
     assertCommit();
     assertSingleConnection();
   }
