@@ -1,5 +1,5 @@
-/*
- *    Copyright 2010-2012 The MyBatis Team
+/**
+ *    Copyright 2010-2015 the original author or authors.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ package org.mybatis.spring.mapper;
  */
 // implementation of MapperInterface to test conflicting types
 final class MapperImplementation implements MapperInterface {
+  @Override
   public void method() {
   }
 }
