@@ -1,5 +1,5 @@
-/*
- *    Copyright 2010-2013 The MyBatis Team
+/**
+ *    Copyright 2010-2016 the original author or authors.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -32,7 +32,7 @@ public class SampleEnableTest extends AbstractSampleTest {
 
 	@Configuration
 	@ImportResource("classpath:org/mybatis/spring/sample/config/applicationContext-infrastructure.xml")
-	@MapperScan("org.mybatis.spring.sample.dao")
+	@MapperScan("org.mybatis.spring.sample.mapper")
 	static class AppConfig {
 	}
 }
