@@ -1,5 +1,5 @@
-/*
- *    Copyright 2010-2012 The MyBatis Team
+/**
+ *    Copyright 2010-2015 the original author or authors.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -42,6 +42,7 @@ public class User {
     this.name = name;
   }
 
+  @Override
   public String toString() {
     StringBuilder buf = new StringBuilder(30);
     buf.append("{");
